@@ -7,12 +7,12 @@ linkname="${TARBALL}"
 linkurl="${baseurl}/jobs/${CI_JOB_ID}/artifacts/${fullname}"
 linklist="[{\"name\": \"${linkname}\", \"url\": \"${linkurl}\"}]"
 
-# descr="$(curl -H \"PRIVATE-TOKEN:\ ${PRIVATE_TOKEN}\" ${baseurl}/repository/tags/${CI_COMMIT_TAG}|jq -r '.message')"
-descr="$(./ci/relnotes.sh ${CI_COMMIT_TAG})"
+descr="$(curl -H \"PRIVATE-TOKEN:\ ${PRIVATE_TOKEN}\" ${baseurl}/repository/tags/${CI_COMMIT_TAG}|jq -r '.message')"
+# descr="$(./ci/relnotes.sh ${CI_COMMIT_TAG})"
 
 DATA="
 {
-  \"name\": \"${progname} version ${CI_COMMIT_TAG}\",
+  \"name\": \"Version ${CI_COMMIT_TAG}\",
   \"description\": \"${descr}\",
   \"tag_name\": \"${CI_COMMIT_TAG}\",
   \"assets\": {
